==> kadu-0.3.9.tar.bz2: kadu/modules/speech/translations/speech_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Notify by speech</source>
        <translation>Notifica con voce</translation>
    </message>
    <message>
        <source>Say only when chat window is not active</source>
        <translation>Parla soltanto se finestra non è attiva</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenza</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>frequenza di base</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Syntesi di Klatt (dsp richiesto)</translation>
    </message>
    <message>
        <source>Use aRts</source>
        <translation>Usi aRts</translation>
    </message>
    <message>
        <source>Use Esd</source>
        <translation>Usi Esd</translation>
    </message>
    <message>
        <source>Use Dsp</source>
        <translation>Usi DSP</translation>
    </message>
    <message>
        <source>Dsp device:</source>
        <translation>Dispositivo DSP:</translation>
    </message>
    <message>
        <source>Speech program:</source>
        <translation>Programma parlante:</translation>
    </message>
    <message>
        <source>Chat format (male):</source>
        <translation>Chat format (maschio):</translation>
    </message>
    <message>
        <source>Chat format (female):</source>
        <translation>Chat format (femmina):</translation>
    </message>
    <message>
        <source>Message format (male):</source>
        <translation>Formato messaggio (maschio):</translation>
    </message>
    <message>
        <source>Notify format (male):</source>
        <translation>Formato notifica (maschio):</translation>
    </message>
    <message>
        <source>Notify format (female):</source>
        <translation>Formato notifica (femmina):</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Prova</translation>
    </message>
    <message>
        <source>Message format (female):</source>
        <translation>Formato messaggio (femmina):</translation>
    </message>
    <message>
        <source>Program</source>
        <translation>Programma</translation>
    </message>
    <message>
        <source>Speech</source>
        <translation>Spech</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodia</translation>
    </message>
</context>
<context>
    <name>SpeechSlots</name>
    <message>
        <source>man %a said %1</source>
        <translation>%a (uomo) ha scritto %1</translation>
    </message>
    <message>
        <source>woman %a said %1</source>
        <translation>%a (donna) ha scritto %1</translation>
    </message>
    <message>
        <source>man %a changed status to %s %d</source>
        <translation>%a (uomo) ha cambiato status a %s %d</translation>
    </message>
    <message>
        <source>woman %a changed status to %s %d</source>
        <translation>%a (donna) ha cambiato status a %s %d</translation>
    </message>
</context>
</TS>

==> kadu-0.4.1.tar.bz2: kadu/modules/speech/translations/speech_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Say only when chat window is not active</source>
        <translation>Parla soltanto se finestra non è attiva</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenza</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>frequenza di base</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Syntesi di Klatt (dsp richiesto)</translation>
    </message>
    <message>
        <source>Use aRts</source>
        <translation>Usi aRts</translation>
    </message>
    <message>
        <source>Use Esd</source>
        <translation>Usi Esd</translation>
    </message>
    <message>
        <source>Use Dsp</source>
        <translation>Usi DSP</translation>
    </message>
    <message>
        <source>Dsp device:</source>
        <translation>Dispositivo DSP:</translation>
    </message>
    <message>
        <source>Speech program:</source>
        <translation>Programma parlante:</translation>
    </message>
    <message>
        <source>Chat format (male):</source>
        <translation>Chat format (maschio):</translation>
    </message>
    <message>
        <source>Chat format (female):</source>
        <translation>Chat format (femmina):</translation>
    </message>
    <message>
        <source>Message format (male):</source>
        <translation>Formato messaggio (maschio):</translation>
    </message>
    <message>
        <source>Notify format (male):</source>
        <translation>Formato notifica (maschio):</translation>
    </message>
    <message>
        <source>Notify format (female):</source>
        <translation>Formato notifica (femmina):</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Prova</translation>
    </message>
    <message>
        <source>Message format (female):</source>
        <translation>Formato messaggio (femmina):</translation>
    </message>
    <message>
        <source>Program</source>
        <translation>Programma</translation>
    </message>
    <message>
        <source>Speech</source>
        <translation>Spech</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodia</translation>
    </message>
    <message>
        <source>Connection error:</source>
        <translation>Errore connessione:</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Quatntià massima delle lettere pronunciate</translation>
    </message>
    <message>
        <source>Message too long (male):</source>
        <translation>Messaggio troppo lungo (maschio):</translation>
    </message>
    <message>
        <source>Message too long (female):</source>
        <translation>Messaggio tropo lungo (femmina):</translation>
    </message>
</context>
<context>
    <name>SpeechSlots</name>
    <message>
        <source>man %a changed status to %s %d</source>
        <translation>%a (uomo) ha cambiato status a %s %d</translation>
    </message>
    <message>
        <source>woman %a changed status to %s %d</source>
        <translation>%a (donna) ha cambiato status a %s %d</translation>
    </message>
    <message>
        <source>Connection error - %1</source>
        <translation>Errore connessione - %1</translation>
    </message>
    <message>
        <source>man %a wrote %1</source>
        <translation>Un certo %a ha scritto %1</translation>
    </message>
    <message>
        <source>woman %a wrote %1</source>
        <translation>Una certa %a ha scritto %1</translation>
    </message>
    <message>
        <source>%a wrote long message</source>
        <translation>%a ha scritto messaggio lungo </translation>
    </message>
</context>
</TS>
